@@ -3,9 +3,9 @@ package alibaba
 import (
 	"context"
 	"crypto/hmac"
+	"crypto/rand"
 	"crypto/sha1"
 	"encoding/base64"
-	"math/rand"
 	"net/http"
 	"net/url"
 	"regexp"
@@ -38,7 +38,6 @@ func (s Scanner) Keywords() []string {
 }
 
 func randString(n int) string {
-	rand.Seed(time.Now().UnixNano())
 	const alphanum = "0123456789abcdefghijklmnopqrstuvwxyz"
 	var bytes = make([]byte, n)
 	rand.Read(bytes)
