@@ -13,7 +13,34 @@ import (
 	"github.com/trufflesecurity/trufflehog/v3/pkg/common"
 )
 
-type Scanner struct{}
+const defaultURL = "https://api.github.com"
+
+type Scanner struct {
+	verifierURLs []string
+}
+
+// New creates a new Scanner with the given options.
+func New(opts ...func(*Scanner)) *Scanner {
+	scanner := &Scanner{
+		verifierURLs: make([]string, 0),
+	}
+	for _, opt := range opts {
+		opt(scanner)
+	}
+
+	return scanner
+}
+
+// WithVerifierURLs adds the given URLs to the list of URLs to check for
+// verification of secrets.
+func WithVerifierURLs(urls []string, includeDefault bool) func(*Scanner) {
+	return func(s *Scanner) {
+		if includeDefault {
+			urls = append(urls, defaultURL)
+		}
+		s.verifierURLs = append(s.verifierURLs, urls...)
+	}
+}
 
 // Ensure the Scanner satisfies the interfaces at compile time.
 var _ detectors.Detector = (*Scanner)(nil)
@@ -29,7 +56,7 @@ var (
 	// https://github.blog/changelog/2022-10-18-introducing-fine-grained-personal-access-tokens/
 	keyPat = regexp.MustCompile(`\b((?:ghp|gho|ghu|ghs|ghr|github_pat)_[a-zA-Z0-9_]{36,255})\b`)
 
-	//TODO: Oauth2 client_id and client_secret
+	// TODO: Oauth2 client_id and client_secret
 	// https://developer.github.com/v3/#oauth2-keysecret
 )
 
@@ -71,27 +98,29 @@ func (s Scanner) FromData(ctx context.Context, verify bool, data []byte) (result
 		if verify {
 			client := common.SaneHttpClient()
 			// https://developer.github.com/v3/users/#get-the-authenticated-user
-			req, err := http.NewRequestWithContext(ctx, "GET", "https://api.github.com/user", nil)
-			if err != nil {
-				continue
-			}
-			req.Header.Add("Content-Type", "application/json; charset=utf-8")
-			req.Header.Add("Authorization", fmt.Sprintf("token %s", token))
-			res, err := client.Do(req)
-			if err == nil {
-				if res.StatusCode >= 200 && res.StatusCode < 300 {
-					var userResponse userRes
-					err = json.NewDecoder(res.Body).Decode(&userResponse)
-					res.Body.Close()
-					if err == nil {
-						s1.Verified = true
-						s1.ExtraData = map[string]string{
-							"username":     userResponse.Login,
-							"url":          userResponse.UserURL,
-							"account_type": userResponse.Type,
-							"site_admin":   fmt.Sprintf("%t", userResponse.SiteAdmin),
-							"name":         userResponse.Name,
-							"company":      userResponse.Company,
+			for _, url := range s.verifierURLs {
+				req, err := http.NewRequestWithContext(ctx, "GET", fmt.Sprintf("%s/user", url), nil)
+				if err != nil {
+					continue
+				}
+				req.Header.Add("Content-Type", "application/json; charset=utf-8")
+				req.Header.Add("Authorization", fmt.Sprintf("token %s", token))
+				res, err := client.Do(req)
+				if err == nil {
+					if res.StatusCode >= 200 && res.StatusCode < 300 {
+						var userResponse userRes
+						err = json.NewDecoder(res.Body).Decode(&userResponse)
+						res.Body.Close()
+						if err == nil {
+							s1.Verified = true
+							s1.ExtraData = map[string]string{
+								"username":     userResponse.Login,
+								"url":          userResponse.UserURL,
+								"account_type": userResponse.Type,
+								"site_admin":   fmt.Sprintf("%t", userResponse.SiteAdmin),
+								"name":         userResponse.Name,
+								"company":      userResponse.Company,
+							}
 						}
 					}
 				}
